Client

Struct Client 

pub struct Client { /* private fields */ }
A connection to an Assuan server.

Commands may be issued using Connection::send. Note that the command is sent lazily, i.e. it is only sent if you poll for the responses.

Client implements Stream to return all server responses until the first Response::Ok, Response::Error, or Response::Inquire.

Response::Ok and Response::Error indicate success and failure. Response::Inquire means that the server requires more information to complete the request. This information may be provided using Connection::data(), or the operation may be canceled using Connection::cancel().

Implementations

Source

impl Client

pub async fn connect<P>(path: P) -> Result<Client, Error>
where P: AsRef<Path>,

Connects to the server.

pub fn send<'a, C>(&'a mut self, command: C) -> Result<(), Error>
where C: AsRef<[u8]> + 'a,

Lazily sends a command to the server.

For the command to be actually executed, stream the responses using this objects Stream implementation.

Note: It is very important to poll the client object until it returns None. Otherwise, the server and client will lose synchronization, and requests and responses will no longer be correctly associated.

The response stream ends in either a Response::Ok, Response::Error, or Response::Inquire. Ok and Error indicate success and failure of the current operation. Inquire means that the server requires more information to complete the request. This information may be provided using Connection::data(), or the operation may be canceled using Connection::cancel().

Note: command is passed as-is. Control characters, like %, must be %-escaped using escape.

pub async fn send_simple<C>(&mut self, cmd: C) -> Result<Protected, Error>
where C: AsRef<str>,

Sends a simple command to the server and returns the response.

This method can only be used with simple commands, i.e. those which do not require handling inquiries from the server. To send complex commands, use Client::send and handle the inquiries.

pub fn cancel(&mut self) -> Result<(), Error>

Lazily cancels a pending operation.

For the command to be actually executed, stream the responses using this objects Stream implementation.

pub fn data<'a, C>(&'a mut self, data: C) -> Result<(), Error>
where C: AsRef<[u8]> + 'a,

Lazily sends data in response to an inquire.

For the command to be actually executed, stream the responses using this objects Stream implementation.

The response stream ends in either a Response::Ok, Response::Error, or another Response::Inquire. Ok and Error indicate success and failure of the original operation that lead to the current inquiry.

pub fn trace_data_sent(&mut self, fun: Box<dyn Fn(&[u8]) + Send + Sync>)

Start tracing the data that is sent to the server.

Note: if a tracing function is already registered, this replaces it.

pub fn trace_data_received(&mut self, fun: Box<dyn Fn(&[u8]) + Send + Sync>)

Start tracing the data that is received from the server.

Note: if a tracing function is already registered, this replaces it.