KeyInfo

Struct KeyInfo 

pub struct KeyInfo { /* private fields */ }
Information about a key.

Returned by Agent::list_keys.

Implementations

Source

impl KeyInfo

pub fn keygrip(&self) -> &Keygrip

Returns the key’s keygrip.

pub fn keytype(&self) -> KeyType

Returns the key’s type.

pub fn serialno(&self) -> Option<&str>

Returns the serial number of the smartcard.

If the key is not on a smartcard, this returns None.

pub fn idstr(&self) -> Option<&str>

Returns the key’s identifier on the smartcard.

If the key is not on a smartcard, this returns None. Example: OPENPGP.1.

pub fn passphrase_cached(&self) -> bool

Returns whether the passphrase for the key was found in the key cache.

pub fn protection(&self) -> &KeyProtection

Returns the key’s protection, if any.

pub fn ttl(&self) -> Option<u64>

Returns the TTL in seconds for the key.

If not available, returns None.

pub fn key_disabled(&self) -> bool

Returns whether the key has been disabled.

pub fn in_ssh_control(&self) -> bool

Returns whether the key is listed in sshcontrol.

pub fn confirmation_required(&self) -> bool

Returns whether use of the key needs to be confirmed.