pub struct Client { /* private fields */ }Expand description
A connection to an Assuan server.
Commands may be issued using Connection::send. Note that the
command is sent lazily, i.e. it is only sent if you poll for the
responses.
Client implements Stream to return all server responses
until the first Response::Ok, Response::Error, or
Response::Inquire.
Response::Ok and Response::Error indicate success and
failure. Response::Inquire means that the server requires
more information to complete the request. This information may be
provided using Connection::data(), or the operation may be
canceled using Connection::cancel().
Implementations
Sourceimpl Client
impl Client
Sourcepub fn send<'a, C>(&'a mut self, command: C) -> Result<(), Error>
pub fn send<'a, C>(&'a mut self, command: C) -> Result<(), Error>
Lazily sends a command to the server.
For the command to be actually executed, stream the responses
using this objects Stream implementation.
Note: It is very important to poll the client object until it
returns None. Otherwise, the server and client will lose
synchronization, and requests and responses will no longer be
correctly associated.
The response stream ends in either a Response::Ok,
Response::Error, or Response::Inquire. Ok and
Error indicate success and failure of the current operation.
Inquire means that the server requires more information to
complete the request. This information may be provided using
Connection::data(), or the operation may be canceled using
Connection::cancel().
Note: command is passed as-is. Control characters, like
%, must be %-escaped using escape.
Sourcepub async fn send_simple<C>(&mut self, cmd: C) -> Result<Protected, Error>
pub async fn send_simple<C>(&mut self, cmd: C) -> Result<Protected, Error>
Sends a simple command to the server and returns the response.
This method can only be used with simple commands, i.e. those
which do not require handling inquiries from the server. To
send complex commands, use Client::send and handle the
inquiries.
Sourcepub fn cancel(&mut self) -> Result<(), Error>
pub fn cancel(&mut self) -> Result<(), Error>
Lazily cancels a pending operation.
For the command to be actually executed, stream the responses
using this objects Stream implementation.
Sourcepub fn data<'a, C>(&'a mut self, data: C) -> Result<(), Error>
pub fn data<'a, C>(&'a mut self, data: C) -> Result<(), Error>
Lazily sends data in response to an inquire.
For the command to be actually executed, stream the responses
using this objects Stream implementation.
The response stream ends in either a Response::Ok,
Response::Error, or another Response::Inquire. Ok
and Error indicate success and failure of the original
operation that lead to the current inquiry.