pub struct KeyInfo { /* private fields */ }Expand description
Information about a key.
Returned by Agent::list_keys.
Implementations
Sourceimpl KeyInfo
impl KeyInfo
Sourcepub fn serialno(&self) -> Option<&str>
pub fn serialno(&self) -> Option<&str>
Returns the serial number of the smartcard.
If the key is not on a smartcard, this returns None.
Sourcepub fn idstr(&self) -> Option<&str>
pub fn idstr(&self) -> Option<&str>
Returns the key’s identifier on the smartcard.
If the key is not on a smartcard, this returns None.
Example: OPENPGP.1.
Sourcepub fn passphrase_cached(&self) -> bool
pub fn passphrase_cached(&self) -> bool
Returns whether the passphrase for the key was found in the key cache.
Sourcepub fn protection(&self) -> &KeyProtection
pub fn protection(&self) -> &KeyProtection
Returns the key’s protection, if any.
Sourcepub fn ttl(&self) -> Option<u64>
pub fn ttl(&self) -> Option<u64>
Returns the TTL in seconds for the key.
If not available, returns None.
Sourcepub fn key_disabled(&self) -> bool
pub fn key_disabled(&self) -> bool
Returns whether the key has been disabled.
Sourcepub fn in_ssh_control(&self) -> bool
pub fn in_ssh_control(&self) -> bool
Returns whether the key is listed in sshcontrol.
Sourcepub fn confirmation_required(&self) -> bool
pub fn confirmation_required(&self) -> bool
Returns whether use of the key needs to be confirmed.